/* ATTINY_85
 *                                       _*__________
 *         (PCINT5/RESET/ADC0/dW) PB5 -- | 1      8 | --  VCC  1.5 to 5.5 VDC
 *  (PCINT3/XTAL1/CLKI/OC1B/ADC3) PB3 -- | 2      7 | --  PB2 (SCK/USCK/SCL/ADC1/T0/INT0/PCINT2)
 *  (PCINT4/XTAL2/CLKO/OC1B/ADC2) PB4 -- | 3      6 | --  PB1 (MISO/DO/AIN1/OC0B/OC1A/PCINT1)
 *                                GND -- | 4      5 | --  PB0 (MOSI/DI/SDA/AIN0/OC0A/OC1A/AREF/PCINT0)
 *                                        ----------                                                           
 *                                        
 *  To program you'll need an Arduino and a breadboard or a custom made shield                                      
 *  Examples:
 *  https://www.instructables.com/id/Program-an-ATtiny-with-Arduino/
 *  https://www.instructables.com/id/ATtiny-Programming-Shield-for-Arduino-1/                               
 *  https://www.instructables.com/id/Arduino-Attiny-Programming-Shield/
 *  
 */
  
/*
 * For this project I used Pololu Addressable LEDs
 * https://www.pololu.com/product/2535
 * 
 *  _______
 * [       ]------ Digital In --> connect to physical pin 5 (PB0) on ATTiny85
 * [       ]------ 5 V (max in)
 * [       ]------------ Ground
 * [_______]------------- Digital Out
 * 
 */

 /*
  * How to power with 9V battery & LM7805
  * https://www.sparkfun.com/datasheets/Components/LM7805.pdf
  * 
  * 9V battery positive terminal to swtich then to LM7805 input then to ATTiny85 physical pin 8 (VCC) 
  * 9V battery negative terminal to LM7805 input common and to ATTiny85 physical pin 4 (GND) and to both LEDs Ground
  * Connect LED Digital in to ATTiny85 physical pin 5 (PB0) on ATTiny85
  * Digital 
  * 
  */

// use Adafruit NeoPixel Library
// https://github.com/adafruit/Adafruit_NeoPixel
// https://learn.adafruit.com/adafruit-neopixel-uberguide?view=all
 
#include <Adafruit_NeoPixel.h>

// Parameter 1 = number of pixels in strip
// Parameter 2 = Arduino pin number (most are valid)
// Parameter 3 = pixel type flags, add together as needed:
//   NEO_KHZ800  800 KHz bitstream (most NeoPixel products w/WS2812 LEDs)
//   NEO_KHZ400  400 KHz (classic 'v1' (not v2) FLORA pixels, WS2811 drivers)
//   NEO_GRB     Pixels are wired for GRB bitstream (most NeoPixel products)
//   NEO_RGB     Pixels are wired for RGB bitstream (v1 FLORA pixels, not v2)
//   NEO_RGBW    Pixels are wired for RGBW bitstream (NeoPixel RGBW products)

Adafruit_NeoPixel strip = Adafruit_NeoPixel(LED_COUNT, PIN, NEO_RGB + NEO_KHZ800);

// setup poer - needed for ATTiny85
#ifdef __AVR__
  #include <avr/power.h>
#endif

#define PIN 0  // physical Pin 5 (PB0) on ATTiny85 is addressed in software as Pin 0
#define LED_COUNT 1  // define number of LED's used

/*
 * How to write to the LED
 * 
 * RGB 0 t0 255 values
 * strip.write(LED #, RED, GREEN, BLUE); 
 * strip.write(0, 150, 0, 0); // RED
 * strip.write(0, 0, 150, 0); // Green
 * strip.write(0, 0, 0, 150); // Blue
 * strip.write(0, 150, 150, 150); // White
 * strip.write(0, 150, 150, 0); // Yellow
 * strip.write(0, 150, 0, 150); // Magenta
 * strip.write(0, 0, 150, 150); // Cyan
 * 
 */

void setup(){
  strip.setPixelColor(0, 0, 0, 0);  // led off at start (otherwise will be blue for a sec or so)
  strip.begin();
  strip.show();  
}

void loop() {

  strip.setPixelColor(0, 150, 0, 0); // Red 15 sec      
  strip.show();
  delay(15000);

  strip.setPixelColor(0, 0, 150, 0); // Green 15 sec      
  strip.show();
  delay(15000);

  strip.setPixelColor(0, 0, 0, 150); // Blue 15 sec      
  strip.show();
  delay(15000);

  strip.setPixelColor(0, 150, 150, 150); // White 15 sec      
  strip.show();
  delay(15000);

  strip.setPixelColor(0, 150, 150, 0); // Yellow 15 sec      
  strip.show();
  delay(15000);

  strip.setPixelColor(0, 150, 0, 150); // Magenta 15 sec      
  strip.show();
  delay(15000);

  strip.setPixelColor(0, 0, 150, 150); // Cyan 15 sec      
  strip.show();
  delay(15000);

  pcr(); //optional  
}

void pcr() {  //off for 3 sec
  strip.setPixelColor(0, 0, 0, 0);
  strip.show();
  delay(3000);
}

